@@ -33,14 +33,15 @@ class CeilometerClientPlugin(client_plugin.ClientPlugin):
         args = {
             'auth_url': con.auth_url,
             'service_type': self.METERING,
-            'project_name': con.tenant,
+            'project_id': con.tenant_id,
             'token': lambda: self.auth_token,
             'endpoint_type': endpoint_type,
             'os_endpoint': endpoint,
             'cacert': self._get_client_option('ceilometer', 'ca_file'),
             'cert_file': self._get_client_option('ceilometer', 'cert_file'),
             'key_file': self._get_client_option('ceilometer', 'key_file'),
-            'insecure': self._get_client_option('ceilometer', 'insecure')
+            'insecure': self._get_client_option('ceilometer', 'insecure'),
+            'aodh_endpoint': endpoint
         }
 
         return cc.get_client('2', **args)
