@@ -80,6 +80,15 @@ class GetParam(function.Function):
                 raise TypeError(_('Path components in "%s" '
                                   'must be strings') % self.fn_name)
 
+            if isinstance(collection, collections.Sequence
+                          ) and isinstance(key, six.string_types):
+                try:
+                    key = int(key)
+                except ValueError:
+                    raise TypeError(_("Path components in '%s' "
+                                      "must be a string that can be "
+                                      "parsed into an "
+                                      "integer.") % self.fn_name)
             return collection[key]
 
         try:
@@ -238,8 +247,9 @@ class Replace(cfn_funcs.Replace):
 
         "<value_1> <value_2>"
 
-    This is implemented using Python's str.replace on each key. The order in
-    which replacements are performed is undefined.
+    This is implemented using python str.replace on each key. Longer keys are
+    substituted before shorter ones, but the order in which replacements are
+    performed is otherwise undefined.
     """
 
     def _parse_args(self):
@@ -266,9 +276,25 @@ class ReplaceJson(Replace):
     '''
     A function for performing string substitutions.
 
-    Behaves the same as Replace, but tolerates non-string parameter
-    values, e.g map/list - these are serialized as json before doing
-    the string substitution.
+    Takes the form::
+
+        str_replace:
+          template: <key_1> <key_2>
+          params:
+            <key_1>: <value_1>
+            <key_2>: <value_2>
+            ...
+
+    And resolves to::
+
+        "<value_1> <value_2>"
+
+    This is implemented using python str.replace on each key. Longer keys are
+    substituted before shorter ones, but the order in which replacements are
+    performed is otherwise undefined.
+
+    Non-string param values (e.g maps or lists) are serialized as JSON before
+    being substituted in.
     '''
 
     def result(self):
@@ -310,6 +336,9 @@ class ReplaceJson(Replace):
 
             return string.replace(placeholder, six.text_type(value))
 
+        mapping = collections.OrderedDict(sorted(mapping.items(),
+                                                 key=lambda t: len(t[0]),
+                                                 reverse=True))
         return six.moves.reduce(replace, six.iteritems(mapping), template)
 
 
@@ -490,7 +519,7 @@ class Repeat(function.Function):
                             self.fn_name)
 
         try:
-            for_each = function.resolve(self.args['for_each'])
+            for_each = self.args['for_each']
             template = self.args['template']
         except (KeyError, TypeError):
             example = ('''repeat:
@@ -500,13 +529,14 @@ class Repeat(function.Function):
             raise KeyError(_('"repeat" syntax should be %s') %
                            example)
 
-        if not isinstance(for_each, collections.Mapping):
-            raise TypeError(_('The "for_each" argument to "%s" must contain '
-                              'a map') % self.fn_name)
-        for v in six.itervalues(for_each):
-            if not isinstance(v, list):
-                raise TypeError(_('The values of the "for_each" argument to '
-                                  '"%s" must be lists') % self.fn_name)
+        if not isinstance(for_each, function.Function):
+            if not isinstance(for_each, collections.Mapping):
+                raise TypeError(_('The "for_each" argument to "%s" must '
+                                  'contain a map') % self.fn_name)
+            for v in six.itervalues(for_each):
+                if not isinstance(v, (list, function.Function)):
+                    raise TypeError(_('The values of the "for_each" argument '
+                                      'to "%s" must be lists') % self.fn_name)
 
         return for_each, template
 
@@ -524,9 +554,15 @@ class Repeat(function.Function):
                         for (k, v) in template.items())
 
     def result(self):
-        keys = list(six.iterkeys(self._for_each))
-        lists = [self._for_each[key] for key in keys]
+        for_each = function.resolve(self._for_each)
+        keys = list(six.iterkeys(for_each))
+        lists = [for_each[key] for key in keys]
+        if not all(isinstance(l, list) for l in lists):
+            raise TypeError(_('The values of the "for_each" argument to '
+                              '"%s" must be lists') % self.fn_name)
+
         template = function.resolve(self._template)
+
         return [self._do_replacement(keys, items, template)
                 for items in itertools.product(*lists)]
 
