@@ -152,7 +152,7 @@ class MonascaAlarmDefinition(resource.Resource):
                 actions_enabled=actions_enabled
             )
 
-    def handle_update(self, prop_diff, json_snippet=None, tmpl_diff=None):
+    def handle_update(self, json_snippet, tmpl_diff, prop_diff):
         args = dict(alarm_id=self.resource_id)
 
         if prop_diff.get(self.NAME):
