@@ -555,6 +555,9 @@ class Server(stack_user.StackUser, sh.SchedulerHintsMixin,
         meta['deployments'] = meta.get('deployments', [])
         meta['os-collect-config'] = meta.get('os-collect-config', {})
         occ = meta['os-collect-config']
+        collectors = ['ec2']
+        occ['collectors'] = collectors
+
         # set existing values to None to override any boot-time config
         occ_keys = ('heat', 'zaqar', 'cfn', 'request')
         for occ_key in occ_keys:
@@ -572,21 +575,18 @@ class Server(stack_user.StackUser, sh.SchedulerHintsMixin,
                 'project_id': self.stack.stack_user_project_id,
                 'stack_id': self.stack.identifier().stack_path(),
                 'resource_name': self.name}})
+            collectors.append('heat')
 
         elif self.transport_zaqar_message(props):
             queue_id = self.physical_resource_name()
             self.data_set('metadata_queue_id', queue_id)
-            zaqar_plugin = self.client_plugin('zaqar')
-            zaqar = zaqar_plugin.create_for_tenant(
-                self.stack.stack_user_project_id)
-            queue = zaqar.queue(queue_id)
-            queue.post({'body': meta, 'ttl': zaqar_plugin.DEFAULT_TTL})
             occ.update({'zaqar': {
                 'user_id': self._get_user_id(),
                 'password': self.password,
                 'auth_url': self.context.auth_url,
                 'project_id': self.stack.stack_user_project_id,
                 'queue_id': queue_id}})
+            collectors.append('zaqar')
 
         elif self.transport_poll_server_cfn(props):
             occ.update({'cfn': {
@@ -595,6 +595,7 @@ class Server(stack_user.StackUser, sh.SchedulerHintsMixin,
                 'secret_access_key': self.secret_key,
                 'stack_name': self.stack.name,
                 'path': '%s.Metadata' % self.name}})
+            collectors.append('cfn')
 
         elif self.transport_poll_temp_url(props):
             container = self.physical_resource_name()
@@ -611,13 +612,28 @@ class Server(stack_user.StackUser, sh.SchedulerHintsMixin,
             self.data_set('metadata_put_url', put_url)
             self.data_set('metadata_object_name', object_name)
 
+            collectors.append('request')
             occ.update({'request': {
                 'metadata_url': url}})
+
+        collectors.append('local')
+        self.metadata_set(meta)
+
+        # push replacement polling config to any existing push-based sources
+        queue_id = self.data().get('metadata_queue_id')
+        if queue_id:
+            zaqar_plugin = self.client_plugin('zaqar')
+            zaqar = zaqar_plugin.create_for_tenant(
+                self.stack.stack_user_project_id, self._user_token())
+            queue = zaqar.queue(queue_id)
+            queue.post({'body': meta, 'ttl': zaqar_plugin.DEFAULT_TTL})
+
+        object_name = self.data().get('metadata_object_name')
+        if object_name:
+            container = self.physical_resource_name()
             self.client('swift').put_object(
                 container, object_name, jsonutils.dumps(meta))
 
-        self.metadata_set(meta)
-
     def _register_access_key(self):
         '''
         Access is limited to this resource, which created the keypair
@@ -734,7 +750,8 @@ class Server(stack_user.StackUser, sh.SchedulerHintsMixin,
         scheduler_hints = self._scheduler_hints(
             self.properties[self.SCHEDULER_HINTS])
 
-        nics = self._build_nics(self.properties[self.NETWORKS])
+        nics = self._build_nics(self.properties[self.NETWORKS],
+                                security_groups=security_groups)
         block_device_mapping = self._build_block_device_mapping(
             self.properties[self.BLOCK_DEVICE_MAPPING])
         block_device_mapping_v2 = self._build_block_device_mapping_v2(
@@ -995,12 +1012,13 @@ class Server(stack_user.StackUser, sh.SchedulerHintsMixin,
         updaters = []
         new_networks = prop_diff.get(self.NETWORKS)
         old_networks = self.properties[self.NETWORKS]
+        security_groups = self.properties[self.SECURITY_GROUPS]
 
         if not server:
             server = self.client().servers.get(self.resource_id)
         interfaces = server.interface_list()
         remove_ports, add_nets = self.calculate_networks(
-            old_networks, new_networks, interfaces)
+            old_networks, new_networks, interfaces, security_groups)
 
         for port in remove_ports:
             updaters.append(
@@ -1323,6 +1341,9 @@ class Server(stack_user.StackUser, sh.SchedulerHintsMixin,
         self._delete_internal_ports()
         self.data_delete('external_ports')
 
+        if self.resource_id is None:
+            return
+
         try:
             self.client().servers.delete(self.resource_id)
         except Exception as e:
@@ -1331,10 +1352,8 @@ class Server(stack_user.StackUser, sh.SchedulerHintsMixin,
         return progress.ServerDeleteProgress(self.resource_id)
 
     def handle_snapshot_delete(self, state):
-        if self.resource_id is None:
-            return
 
-        if state[1] != self.FAILED:
+        if state[1] != self.FAILED and self.resource_id:
             image_id = self.client().servers.create_image(
                 self.resource_id, self.physical_resource_name())
             return progress.ServerDeleteProgress(
@@ -1342,8 +1361,6 @@ class Server(stack_user.StackUser, sh.SchedulerHintsMixin,
         return self._delete()
 
     def handle_delete(self):
-        if self.resource_id is None:
-            return
 
         return self._delete()
 
