@@ -322,6 +322,8 @@ class ResourceDefinition(ResourceDefinitionCore, collections.Mapping):
 
         return super(ResourceDefinition, self).__eq__(other)
 
+    __hash__ = ResourceDefinitionCore.__hash__
+
     def __iter__(self):
         """Iterate over the available CFN template keys.
 
@@ -377,11 +379,6 @@ class ResourceDefinition(ResourceDefinitionCore, collections.Mapping):
 
         raise KeyError(key)
 
-    def __hash__(self):
-        """Return a hash of the ResourceDefinition object."""
-        warnings.warn(self._deprecation_msg, DeprecationWarning)
-        return super(ResourceDefinition, self).__hash__()
-
     def __len__(self):
         """Return the number of available CFN template keys.
 
