@@ -188,6 +188,12 @@ class Stack(collections.Mapping):
 
         if use_stored_context:
             self.context = self.stored_context()
+            self.context.roles = self.context.clients.client(
+                'keystone').auth_ref.role_names
+            self.context.user_domain = self.context.clients.client(
+                'keystone').auth_ref.user_domain_id
+            self.context.project_domain = self.context.clients.client(
+                'keystone').auth_ref.project_domain_id
 
         self.clients = self.context.clients
 
@@ -301,7 +307,8 @@ class Stack(collections.Mapping):
     def dependencies(self):
         if self._dependencies is None:
             self._dependencies = self._get_dependencies(
-                six.itervalues(self.resources))
+                six.itervalues(self.resources),
+                ignore_errors=self.id is not None)
         return self._dependencies
 
     def reset_dependencies(self):
@@ -373,11 +380,22 @@ class Stack(collections.Mapping):
         return set(itertools.chain.from_iterable(attr_lists))
 
     @staticmethod
-    def _get_dependencies(resources):
+    def _get_dependencies(resources, ignore_errors=True):
         """Return the dependency graph for a list of resources."""
         deps = dependencies.Dependencies()
         for res in resources:
-            res.add_dependencies(deps)
+            res.add_explicit_dependencies(deps)
+
+            try:
+                res.add_dependencies(deps)
+            except Exception as exc:
+                if not ignore_errors:
+                    raise
+                else:
+                    LOG.warning(_LW('Ignoring error adding implicit '
+                                    'dependencies for %(res)s: %(err)s') %
+                                {'res': six.text_type(res),
+                                 'err': six.text_type(exc)})
 
         return deps
 
@@ -1207,6 +1225,8 @@ class Stack(collections.Mapping):
         backup_stack = self._backup_stack()
         existing_params = environment.Environment({env_fmt.PARAMETERS:
                                                   self.t.env.params})
+        should_rollback = False
+        previous_template_id = None
         try:
             update_task = update.StackUpdate(
                 self, newstack, backup_stack,
@@ -1247,42 +1267,52 @@ class Stack(collections.Mapping):
         except scheduler.Timeout:
             self.status = self.FAILED
             self.status_reason = 'Timed out'
-        except (ForcedCancel, exception.ResourceFailure) as e:
+        except (ForcedCancel, Exception) as e:
             # If rollback is enabled when resource failure occurred,
             # we do another update, with the existing template,
             # so we roll back to the original state
-            if self._update_exception_handler(
-                    exc=e, action=action, update_task=update_task):
+            should_rollback = self._update_exception_handler(e, action,
+                                                             update_task)
+            if should_rollback:
                 yield self.update_task(oldstack, action=self.ROLLBACK)
-                return
+        except BaseException as e:
+            with excutils.save_and_reraise_exception():
+                self._update_exception_handler(e, action, update_task)
         else:
             LOG.debug('Deleting backup stack')
             backup_stack.delete(backup=True)
 
             # flip the template to the newstack values
+            previous_template_id = self.t.id
             self.t = newstack.t
             template_outputs = self.t[self.t.OUTPUTS]
             self.outputs = self.resolve_static_data(template_outputs)
+        finally:
+            if should_rollback:
+                # Already handled in rollback task
+                return
 
-        # Don't use state_set to do only one update query and avoid race
-        # condition with the COMPLETE status
-        self.action = action
+            # Don't use state_set to do only one update query and avoid race
+            # condition with the COMPLETE status
+            self.action = action
 
-        notification.send(self)
-        self._add_event(self.action, self.status, self.status_reason)
-        if self.status == self.FAILED:
-            # Since template was incrementally updated based on existing and
-            # new stack resources, we should have user params of both.
-            existing_params.load(newstack.t.env.user_env_as_dict())
-            self.t.env = existing_params
-            self.t.store(self.context)
-            backup_stack.t.env = existing_params
-            backup_stack.t.store(self.context)
-        self.store()
+            self._send_notification_and_add_event()
+            if self.status == self.FAILED:
+                # Since template was incrementally updated based on existing
+                # and new stack resources, we should have user params of both.
+                existing_params.load(newstack.t.env.user_env_as_dict())
+                self.t.env = existing_params
+                self.t.store(self.context)
+                backup_stack.t.env = existing_params
+                backup_stack.t.store(self.context)
+            self.store()
 
-        lifecycle_plugin_utils.do_post_ops(self.context, self,
-                                           newstack, action,
-                                           (self.status == self.FAILED))
+            if previous_template_id is not None:
+                raw_template_object.RawTemplate.delete(self.context,
+                                                       previous_template_id)
+            lifecycle_plugin_utils.do_post_ops(self.context, self,
+                                               newstack, action,
+                                               (self.status == self.FAILED))
 
     def _update_exception_handler(self, exc, action, update_task):
         """Handle exceptions in update_task.
@@ -1300,8 +1330,10 @@ class Stack(collections.Mapping):
         if isinstance(exc, ForcedCancel):
             update_task.updater.cancel_all()
             return exc.with_rollback or not self.disable_rollback
-
-        return not self.disable_rollback
+        elif isinstance(exc, exception.ResourceFailure):
+            return not self.disable_rollback
+        else:
+            return False
 
     def _message_parser(self, message):
         if message == rpc_api.THREAD_CANCEL:
