@@ -198,6 +198,9 @@ class Stack(
     def refresh(self):
         db_stack = db_api.stack_get(
             self._context, self.id, show_deleted=True)
+        if db_stack is None:
+            message = _('No stack exists with id "%s"') % str(self.id)
+            raise exception.NotFound(message)
         db_stack.refresh()
         return self.__class__._from_db_object(
             self._context,
