@@ -81,14 +81,14 @@ class TestAutoScalingPolicy(common.HeatTestCase):
         pol = self.create_scaling_policy(t, stack, 'my-policy')
 
         test = {'current': 'not_an_alarm'}
-        with mock.patch.object(pol, '_cooldown_inprogress',
+        with mock.patch.object(pol, '_is_scaling_allowed',
                                side_effect=AssertionError()) as dont_call:
             self.assertRaises(exception.NoActionRequired,
                               pol.handle_signal, details=test)
             self.assertEqual([], dont_call.call_args_list)
 
     def test_scaling_policy_cooldown_toosoon(self):
-        """If _cooldown_inprogress() returns True don't progress."""
+        """If _is_scaling_allowed() returns False don't progress."""
         t = template_format.parse(as_template)
         stack = utils.parse_stack(t, params=as_params)
         pol = self.create_scaling_policy(t, stack, 'my-policy')
@@ -96,8 +96,8 @@ class TestAutoScalingPolicy(common.HeatTestCase):
 
         with mock.patch.object(pol.stack, 'resource_by_refid',
                                side_effect=AssertionError) as dont_call:
-            with mock.patch.object(pol, '_cooldown_inprogress',
-                                   return_value=True) as mock_cip:
+            with mock.patch.object(pol, '_is_scaling_allowed',
+                                   return_value=False) as mock_cip:
                 self.assertRaises(exception.NoActionRequired,
                                   pol.handle_signal, details=test)
                 mock_cip.assert_called_once_with()
@@ -111,12 +111,11 @@ class TestAutoScalingPolicy(common.HeatTestCase):
 
         group = self.patchobject(pol.stack, 'resource_by_refid').return_value
         group.name = 'fluffy'
-        with mock.patch.object(pol, '_cooldown_inprogress',
-                               return_value=False) as mock_cip:
+        with mock.patch.object(pol, '_is_scaling_allowed',
+                               return_value=True) as mock_isa:
             pol.handle_signal(details=test)
-            mock_cip.assert_called_once_with()
-        group.adjust.assert_called_once_with(1, 'change_in_capacity', None,
-                                             signal=True)
+            mock_isa.assert_called_once_with()
+        group.adjust.assert_called_once_with(1, 'change_in_capacity', None)
 
 
 class TestCooldownMixin(common.HeatTestCase):
@@ -139,7 +138,7 @@ class TestCooldownMixin(common.HeatTestCase):
         previous_meta = {'cooldown': {
             now.isoformat(): 'change_in_capacity : 1'}}
         self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertTrue(pol._cooldown_inprogress())
+        self.assertFalse(pol._is_scaling_allowed())
 
     def test_cooldown_is_in_progress_scaling_unfinished(self):
         t = template_format.parse(as_template)
@@ -148,7 +147,7 @@ class TestCooldownMixin(common.HeatTestCase):
 
         previous_meta = {'scaling_in_progress': True}
         self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertTrue(pol._cooldown_inprogress())
+        self.assertFalse(pol._is_scaling_allowed())
 
     def test_cooldown_not_in_progress(self):
         t = template_format.parse(as_template)
@@ -163,7 +162,7 @@ class TestCooldownMixin(common.HeatTestCase):
             'scaling_in_progress': False
         }
         self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertFalse(pol._cooldown_inprogress())
+        self.assertTrue(pol._is_scaling_allowed())
 
     def test_scaling_policy_cooldown_zero(self):
         t = template_format.parse(as_template)
@@ -179,7 +178,7 @@ class TestCooldownMixin(common.HeatTestCase):
         previous_meta = {'cooldown': {
             now.isoformat(): 'change_in_capacity : 1'}}
         self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertFalse(pol._cooldown_inprogress())
+        self.assertTrue(pol._is_scaling_allowed())
 
     def test_scaling_policy_cooldown_none(self):
         t = template_format.parse(as_template)
@@ -196,7 +195,17 @@ class TestCooldownMixin(common.HeatTestCase):
         previous_meta = {'cooldown': {
             now.isoformat(): 'change_in_capacity : 1'}}
         self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertFalse(pol._cooldown_inprogress())
+        self.assertTrue(pol._is_scaling_allowed())
+
+    def test_no_cooldown_no_scaling_in_progress(self):
+        t = template_format.parse(as_template)
+        stack = utils.parse_stack(t, params=as_params)
+        pol = self.create_scaling_policy(t, stack, 'my-policy')
+
+        # no cooldown entry in the metadata
+        previous_meta = {'scaling_in_progress': False}
+        self.patchobject(pol, 'metadata_get', return_value=previous_meta)
+        self.assertTrue(pol._is_scaling_allowed())
 
     def test_metadata_is_written(self):
         t = template_format.parse(as_template)
@@ -207,7 +216,7 @@ class TestCooldownMixin(common.HeatTestCase):
         reason = 'cool as'
         meta_set = self.patchobject(pol, 'metadata_set')
         self.patchobject(timeutils, 'utcnow', return_value=nowish)
-        pol._cooldown_timestamp(reason)
+        pol._finished_scaling(reason)
         meta_set.assert_called_once_with(
             {'cooldown': {nowish.isoformat(): reason},
              'scaling_in_progress': False})
