@@ -10,9 +10,7 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
-from ceilometerclient import client as cc
-from keystoneclient import exceptions
+import ceilometerclient
 
 from heat.tests import common
 from heat.tests import utils
@@ -21,8 +19,18 @@ from heat.tests import utils
 class CeilometerClientPluginTests(common.HeatTestCase):
 
     def test_create(self):
-        self.patchobject(cc.AuthPlugin, 'redirect_to_aodh_endpoint',
-                         side_effect=exceptions.EndpointNotFound)
+        # check version and mock accordingly
+        if ceilometerclient.__version__ >= '2.2':
+            from ceilometerclient.openstack.common.apiclient \
+                import client as cc
+            self.patchobject(cc.HTTPClient, 'client_request')
+        else:
+            # mock redirect_to_aodh_endpoint
+            from ceilometerclient import client as cc
+            from keystoneclient import exceptions
+            self.patchobject(cc.AuthPlugin, 'redirect_to_aodh_endpoint',
+                             side_effect=exceptions.EndpointNotFound)
+
         context = utils.dummy_context()
         plugin = context.clients.client_plugin('ceilometer')
         client = plugin.client()
