@@ -71,7 +71,21 @@ class ResWithShowAttr(GenericResource):
                 'Another': self.name}
 
 
-class ResWithComplexPropsAndAttrs(GenericResource):
+class ResWithStringPropAndAttr(GenericResource):
+
+    properties_schema = {
+        'a_string': properties.Schema(properties.Schema.STRING)}
+
+    attributes_schema = {'string': attributes.Schema('A string')}
+
+    def _resolve_attribute(self, name):
+        try:
+            return self.properties["a_%s" % name]
+        except KeyError:
+            return None
+
+
+class ResWithComplexPropsAndAttrs(ResWithStringPropAndAttr):
 
     properties_schema = {
         'a_string': properties.Schema(properties.Schema.STRING),
@@ -326,3 +340,9 @@ class ResourceTypeUnSupportedLiberty(GenericResource):
 class ResourceTypeSupportedKilo(GenericResource):
     support_status = support.SupportStatus(
         version='2015.1')
+
+
+class ResourceTypeHidden(GenericResource):
+    support_status = support.SupportStatus(
+        version='7.0.0',
+        status=support.HIDDEN)
