@@ -18,6 +18,7 @@ import six
 from heat.common import exception
 from heat.common import identifier
 from heat.common import template_format
+from heat.engine.cfn import functions as cfn_functions
 from heat.engine import environment
 from heat.engine import function
 from heat.engine.hot import functions as hot_functions
@@ -557,6 +558,26 @@ class HOTemplateTest(common.HeatTestCase):
 
         self.assertEqual(snippet_resolved, self.resolve(snippet, tmpl))
 
+    def test_str_replace_order(self, tpl=hot_tpl_empty):
+        """Test str_replace function substitution order."""
+
+        snippet = {'str_replace': {'template': '1234567890',
+                                   'params': {'1': 'a',
+                                              '12': 'b',
+                                              '123': 'c',
+                                              '1234': 'd',
+                                              '12345': 'e',
+                                              '123456': 'f',
+                                              '1234567': 'g'}}}
+
+        tmpl = template.Template(tpl)
+
+        self.assertEqual('g890', self.resolve(snippet, tmpl))
+
+    def test_str_replace_liberty_order(self):
+        """Test str_replace function substitution order."""
+        self.test_str_replace_order(hot_liberty_tpl_empty)
+
     def test_str_replace_syntax(self):
         """
         Test str_replace function syntax.
@@ -610,7 +631,54 @@ class HOTemplateTest(common.HeatTestCase):
         snippet = {'str_replace': {'template': 'Template var1 string var2',
                                    'params': ['var1', 'foo', 'var2', 'bar']}}
 
-        self.assertRaises(TypeError, self.resolve, snippet, tmpl)
+        ex = self.assertRaises(TypeError, self.resolve, snippet, tmpl)
+        self.assertIn('parameters must be a mapping', six.text_type(ex))
+
+    def test_str_replace_invalid_param_type_init(self):
+        """Test str_replace function parameter values.
+
+        Pass parameter values of wrong type to function and verify that we get
+        a TypeError in the constructor.
+        """
+        args = [['var1', 'foo', 'var2', 'bar'],
+                'Template var1 string var2']
+        ex = self.assertRaises(
+            TypeError,
+            cfn_functions.Replace,
+            None, 'Fn::Replace', args)
+        self.assertIn('parameters must be a mapping', six.text_type(ex))
+
+    def test_str_replace_ref_get_param(self):
+        """Test str_replace referencing parameters."""
+        hot_tpl = template_format.parse('''
+        heat_template_version: 2015-04-30
+        parameters:
+          p_template:
+            type: string
+            default: foo-replaceme
+          p_params:
+            type: json
+            default:
+              replaceme: success
+        resources:
+          rsrc:
+            type: ResWithStringPropAndAttr
+            properties:
+              a_string:
+                str_replace:
+                  template: {get_param: p_template}
+                  params: {get_param: p_params}
+        outputs:
+          replaced:
+            value: {get_attr: [rsrc, string]}
+        ''')
+        tmpl = template.Template(hot_tpl)
+        self.stack = parser.Stack(utils.dummy_context(), 'test_stack', tmpl)
+        self.stack.store()
+        self.stack.create()
+        self.assertEqual((parser.Stack.CREATE, parser.Stack.COMPLETE),
+                         self.stack.state)
+        self.assertEqual('foo-success', self.stack.output('replaced'))
 
     def test_get_file(self):
         """Test get_file function."""
@@ -757,6 +825,16 @@ class HOTemplateTest(common.HeatTestCase):
 
     def test_repeat(self):
         """Test repeat function."""
+        snippet = {'repeat': {'template': 'this is %var%',
+                              'for_each': {'%var%': ['a', 'b', 'c']}}}
+        snippet_resolved = ['this is a', 'this is b', 'this is c']
+
+        tmpl = template.Template(hot_kilo_tpl_empty)
+
+        self.assertEqual(snippet_resolved, self.resolve(snippet, tmpl))
+
+    def test_repeat_get_param(self):
+        """Test repeat function with get_param function as an argument."""
         hot_tpl = template_format.parse('''
         heat_template_version: 2015-04-30
         parameters:
@@ -1118,6 +1196,22 @@ class HotStackTest(common.HeatTestCase):
     def resolve(self, snippet):
         return function.resolve(self.stack.t.parse(self.stack, snippet))
 
+    def test_repeat_get_attr(self):
+        """Test repeat function with get_attr function as an argument."""
+        tmpl = template.Template(hot_tpl_complex_attrs_all_attrs)
+        self.stack = parser.Stack(self.ctx, 'test_repeat_get_attr', tmpl)
+
+        snippet = {'repeat': {'template': 'this is %var%',
+                   'for_each': {'%var%': {'get_attr': ['resource1', 'list']}}}}
+        repeat = self.stack.t.parse(self.stack, snippet)
+
+        self.stack.store()
+        self.stack.create()
+        self.assertEqual((parser.Stack.CREATE, parser.Stack.COMPLETE),
+                         self.stack.state)
+        self.assertEqual(['this is foo', 'this is bar'],
+                         function.resolve(repeat))
+
     def test_get_attr_multiple_rsrc_status(self):
         """Test resolution of get_attr occurrences in HOT template."""
 
@@ -1555,6 +1649,10 @@ class StackParametersTest(common.HeatTestCase):
          dict(params={'list': 'foo,bar'},
               snippet={'properties': {'prop1': {'get_param': ['list', 1]}}},
               expected={'properties': {'prop1': 'bar'}})),
+        ('get_list_attr_string_index',
+         dict(params={'list': 'foo,bar'},
+              snippet={'properties': {'prop1': {'get_param': ['list', '1']}}},
+              expected={'properties': {'prop1': 'bar'}})),
         ('get_flat_dict_attr',
          dict(params={'flat_dict':
                       {'key1': 'val1', 'key2': 'val2', 'key3': 'val3'}},
