@@ -77,7 +77,7 @@ Outputs:
     def setUp(self):
         super(AwsStackTest, self).setUp()
         self.object_container_name = AwsStackTest.__name__
-        self.project_id = self.identity_client.auth_ref.project_id
+        self.project_id = self.identity_client.project_id
         self.object_client.put_container(self.object_container_name)
         self.nested_name = '%s.yaml' % test.rand_name()
 
@@ -107,7 +107,7 @@ Outputs:
         full_url = '%s://%s%s' % (sw_url.scheme, sw_url.netloc, tempurl)
 
         def download():
-            r = requests.get(full_url)
+            r = requests.get(full_url, verify=self.verify_cert)
             LOG.info('GET: %s -> %s' % (full_url, r.status_code))
             return r.status_code == requests.codes.ok
 
